==> large-image-source-dicom-1.25.1.dev30.tar.gz: large-image-source-dicom-1.25.1.dev30/setup.py <==
import os

from setuptools import find_packages, setup

description = 'A DICOM tilesource for large_image.'
long_description = description + '\n\nSee the large-image package for more details.'


def prerelease_local_scheme(version):
    """
    Return local scheme version unless building on master in CircleCI.

    This function returns the local scheme version number
    (e.g. 0.0.0.dev<N>+g<HASH>) unless building on CircleCI for a
    pre-release in which case it ignores the hash and produces a
    PEP440 compliant pre-release version number (e.g. 0.0.0.dev<N>).
    """
    from setuptools_scm.version import get_local_node_and_date

    if os.getenv('CIRCLE_BRANCH') in ('master', ):
        return ''
    else:
        return get_local_node_and_date(version)


try:
    from setuptools_scm import get_version

    version = get_version(root='../..', local_scheme=prerelease_local_scheme)
    limit_version = f'>={version}' if '+' not in version else ''
except (ImportError, LookupError):
    limit_version = ''

setup(
    name='large-image-source-dicom',
    use_scm_version={'root': '../..', 'local_scheme': prerelease_local_scheme,
                     'fallback_version': '0.0.0'},
    setup_requires=['setuptools-scm'],
    description=description,
    long_description=long_description,
    license='Apache Software License 2.0',
    author='Kitware, Inc.',
    author_email='kitware@kitware.com',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    install_requires=[
        f'large-image{limit_version}',
        'wsidicom>=0.9.0',
    ],
    extras_require={
        'girder': f'girder-large-image{limit_version}',
    },
    include_package_data=True,
    keywords='large_image, tile source',
    packages=find_packages(exclude=['test', 'test.*', 'test_dicom', 'test_dicom.*']),
    url='https://github.com/girder/large_image',
    python_requires='>=3.8',
    entry_points={
        'large_image.source': [
            'dicom = large_image_source_dicom:DICOMFileTileSource',
        ],
        'girder_large_image.source': [
            'dicom = large_image_source_dicom.girder_source:DICOMGirderTileSource',
        ],
        'girder.plugin': [
            'dicomweb = large_image_source_dicom.girder_plugin:DICOMwebPlugin',
        ],
    },
)

==> large-image-source-dicom-1.26.2.dev19.tar.gz: large-image-source-dicom-1.26.2.dev19/setup.py <==
import os

from setuptools import find_packages, setup

description = 'A DICOM tilesource for large_image.'
long_description = description + '\n\nSee the large-image package for more details.'


def prerelease_local_scheme(version):
    """
    Return local scheme version unless building on master in CircleCI.

    This function returns the local scheme version number
    (e.g. 0.0.0.dev<N>+g<HASH>) unless building on CircleCI for a
    pre-release in which case it ignores the hash and produces a
    PEP440 compliant pre-release version number (e.g. 0.0.0.dev<N>).
    """
    from setuptools_scm.version import get_local_node_and_date

    if os.getenv('CIRCLE_BRANCH') in ('master', ):
        return ''
    else:
        return get_local_node_and_date(version)


try:
    from setuptools_scm import get_version

    version = get_version(root='../..', local_scheme=prerelease_local_scheme)
    limit_version = f'>={version}' if '+' not in version and not os.getenv('TOX_ENV_NAME') else ''
except (ImportError, LookupError):
    limit_version = ''

setup(
    name='large-image-source-dicom',
    use_scm_version={'root': '../..', 'local_scheme': prerelease_local_scheme,
                     'fallback_version': '0.0.0'},
    setup_requires=['setuptools-scm'],
    description=description,
    long_description=long_description,
    license='Apache Software License 2.0',
    author='Kitware, Inc.',
    author_email='kitware@kitware.com',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    install_requires=[
        f'large-image{limit_version}',
        'wsidicom>=0.9.0',
    ],
    extras_require={
        'girder': f'girder-large-image{limit_version}',
    },
    include_package_data=True,
    keywords='large_image, tile source',
    packages=find_packages(exclude=['test', 'test.*', 'test_dicom', 'test_dicom.*']),
    url='https://github.com/girder/large_image',
    python_requires='>=3.8',
    entry_points={
        'large_image.source': [
            'dicom = large_image_source_dicom:DICOMFileTileSource',
        ],
        'girder_large_image.source': [
            'dicom = large_image_source_dicom.girder_source:DICOMGirderTileSource',
        ],
        'girder.plugin': [
            'dicomweb = large_image_source_dicom.girder_plugin:DICOMwebPlugin',
        ],
    },
)
